@@ -35,7 +35,7 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     if(year < 0) year+=100;
     while(year > 100) year-=100;
     
-    mmvprintw(y+1, 5, "source");
+    mvprintw(y+1, 5, "source");
     char tmp[PATH_MAX];
     xstrncpy(tmp, spath, PATH_MAX);
     if(S_ISDIR(stat_.st_mode)) {
@@ -52,9 +52,9 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     }
     
     
-    mmvprintw(y+2, 5, "path: %s", tmp);
-    mmvprintw(y+3, 5, "size: %d", stat_.st_size);
-    mmvprintw(y+4, 5, "time: %02d-%02d-%02d %02d:%02d", year, tm_->tm_mon+1
+    mvprintw(y+2, 5, "path: %s", tmp);
+    mvprintw(y+3, 5, "size: %d", stat_.st_size);
+    mvprintw(y+4, 5, "time: %02d-%02d-%02d %02d:%02d", year, tm_->tm_mon+1
            , tm_->tm_mday, tm_->tm_hour, tm_->tm_min);
     
     t = dfstat.st_mtime;
@@ -64,7 +64,7 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     if(year < 0) year+=100;
     while(year > 100) year-=100;
     
-    mmvprintw(y+6, 5, "distination");
+    mvprintw(y+6, 5, "distination");
     char tmp2[PATH_MAX];
     xstrncpy(tmp2, dfile, PATH_MAX);
     if(S_ISDIR(dfstat.st_mode)) {
@@ -80,9 +80,9 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
         xstrncat(tmp, "@", PATH_MAX);
     }
     
-    mmvprintw(y+7, 5, "path: %s", tmp2);
-    mmvprintw(y+8, 5, "size: %d", dfstat.st_size);
-    mmvprintw(y+9, 5, "time: %02d-%02d-%02d %02d:%02d", year, tm_->tm_mon+1
+    mvprintw(y+7, 5, "path: %s", tmp2);
+    mvprintw(y+8, 5, "size: %d", dfstat.st_size);
+    mvprintw(y+9, 5, "time: %02d-%02d-%02d %02d:%02d", year, tm_->tm_mon+1
            , tm_->tm_mday, tm_->tm_hour, tm_->tm_min);
 }
 
@@ -112,9 +112,9 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     
     if(FD_ISSET(0, &mask)) {
         int meta;
-        int key = mgetch(&meta);
+        int key = xgetch(&meta);
 
-        if(key == 3 || key == 7 || key == 27) {    // CTRL-G and CTRL-C
+        if(key == 3 || key == 7 || key == 27) {   // CTRL-G and CTRL-C
             merr_msg("file_copy: canceled");
             return FALSE;
         }
@@ -262,9 +262,9 @@ override_select_str:
                         
                         gView = NULL;
 
-                        mclear();
+                        clear();
                         view();
-                        mrefresh();
+                        refresh();
                         
                         switch(ret) {
                         case 0:
@@ -499,9 +499,9 @@ override_select_str2:
 
                     gView = NULL;
                     
-                    mclear();
+                    clear();
                     view();
-                    mrefresh();
+                    refresh();
                     
                     switch(ret) {
                     case 0:
@@ -640,9 +640,9 @@ file_copy:
                         
                         if(FD_ISSET(0, &mask)) {
                             int meta;
-                            int key = mgetch(&meta);
+                            int key = xgetch(&meta);
 
-                            if(key == 3 || key == 7 || key == 27) {    // CTRL-G and CTRL-C
+                            if(key == 3 || key == 7 || key == 27) { // CTRL-G and CTRL-C
                                 merr_msg("file_copy: canceled");
                                 close(fd);
                                 close(fd2);
@@ -1055,9 +1055,9 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
     
         if(FD_ISSET(0, &mask)) {
             int meta;
-            int key = mgetch(&meta);
+            int key = xgetch(&meta);
 
-            if(key == 3 || key == 7 || key == 27) {    // CTRL-C and CTRL-G
+            if(key == 3 || key == 7 || key == 27) { // CTRL-C and CTRL-G
                 return FALSE;
             }
         }
