@@ -62,7 +62,7 @@ static void mfiler4_migemo_init();
 static BOOL is_isearch_char(int key)
 {
     return key == 9 || (key >= ' ' && key <= '~')
-                && key != '\\';
+                && key != '\\' || key >= 128;
 }
 
 static char* mystrcasestr(const char *haystack, const char *needle)
@@ -625,9 +625,9 @@ void isearch_view()
     const int maxy = mgetmaxy();
 
     if(gISearchPartMatch) 
-        mmvprintw(maxy -2, 0, "//");
+        mvprintw(maxy -2, 0, "//");
     else
-        mmvprintw(maxy -2, 0, "/");
+        mvprintw(maxy -2, 0, "/");
 
     char buf[1024];
     char* str = string_c_str(gInputFileName);
@@ -642,6 +642,6 @@ void isearch_view()
         }
     }
     buf[i] = 0;
-    mprintw(buf);
+    printw(buf);
 }
 
