@@ -75,10 +75,10 @@ char gHomeDir[PATH_MAX];         // ホームディレクトリ
 static void input(int meta, int key)
 {
     if(key == 26) {         // CTRL-Z
-        mendwin();
+        endwin();
         mreset_tty();
         kill(getpid(), SIGSTOP);
-        minitscr();
+        xinitscr();
     }
     else if(gActiveMenu) {
         /// メニュー ///
@@ -114,7 +114,7 @@ static void job_view()
         
         str_cut(gKanjiCode, buf, maxx/size, buf2, BUFSIZ);
 
-        mmvprintw(maxy-3, x, "%s", buf2);
+        mvprintw(maxy-3, x, "%s", buf2);
     }
 }
 
@@ -150,7 +150,7 @@ static void cmdline_view_filer()
         }
     }
 
-    mmvprintw(maxy-2, 0, SFD(nextout).fdbuf.mBuf);
+    mvprintw(maxy-2, 0, SFD(nextout).fdbuf.mBuf);
 
     (void)vector_pop_back(gStackFrames);
     stack_end_stack();
@@ -247,7 +247,7 @@ static void cmdline_view_filer()
         char buf3[1024];
         str_cut2(gKanjiCode, buf2, maxx-1, buf3, 1024);
                             
-        mmvprintw(maxy-1, 0, "%s", buf3);
+        mvprintw(maxy-1, 0, "%s", buf3);
     }
     else {
         snprintf(buf, 1024,
@@ -266,10 +266,10 @@ static void cmdline_view_filer()
         char buf2[1024];
         str_cut2(gKanjiCode, buf, maxx-1, buf2, 1024);
                    
-        mmvprintw(maxy-1, 0, "%s", buf2);
+        mvprintw(maxy-1, 0, "%s", buf2);
     }
 
-    mmove(maxy-1, maxx-2);
+    move(maxy-1, maxx-2);
 }
 
 void view()
@@ -343,7 +343,7 @@ static void sig_winch(int s)
     if(gMainLoop == -1) {
         mclear_immediately();       // 画面の再描写
         view();
-        mrefresh();
+        refresh();
     }
 }
 
@@ -352,7 +352,7 @@ static void sig_cont(int s)
     if(gMainLoop == -1) {
         mclear_immediately();       // 画面の再描写
         view();
-        mrefresh();
+        refresh();
     }
 }
 
@@ -439,6 +439,8 @@ static void set_mfenv()
     snprintf(buf, 128, "%d", KEY_IC);
     setenv("key_insert", buf, 1);
     snprintf(buf, 128, "%d", KEY_DC);
+    setenv("key_delete2", buf, 1);
+    snprintf(buf, 128, "%d", 127);
     setenv("key_delete", buf, 1);
     snprintf(buf, 128, "%d", KEY_HOME);
     setenv("key_home", buf, 1);
@@ -448,24 +450,7 @@ static void set_mfenv()
     setenv("key_pageup", buf, 1);
     snprintf(buf, 128, "%d", KEY_NPAGE);
     setenv("key_pagedown", buf, 1);
-    snprintf(buf, 128, "%d", KEY_F(13));
-    setenv("key_meta_left", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(14));
-    setenv("key_meta_right", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(15));
-    setenv("key_meta_up", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(16));
-    setenv("key_meta_down", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(17));
-    setenv("key_ctrl_left", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(18));
-    setenv("key_ctrl_right", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(19));
-    setenv("key_ctrl_up", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(20));
-    setenv("key_ctrl_down", buf, 1);
-    snprintf(buf,128, "%d", KEY_F(21));
-    setenv("key_ctrl_delete", buf, 1);
+
     snprintf(buf,128, "%d", 10);
     setenv("key_enter", buf, 1);
     snprintf(buf,128, "%d", KEY_BACKSPACE);
@@ -600,8 +585,6 @@ static void set_mfenv()
     setenv("key_Z", buf, 1);
     snprintf(buf,128, "%d", 32);
     setenv("key_space", buf, 1);
-    snprintf(buf,128, "%d", 0);
-    setenv("key_ctrl_space", buf, 1);
     snprintf(buf,128, "%d", 1);
     setenv("key_ctrl_a", buf, 1);
     snprintf(buf,128, "%d", 2);
@@ -746,25 +729,25 @@ static void set_mfenv()
     setenv("nometa", buf, 1);
     snprintf(buf,128, "%d", 1);
     setenv("meta", buf, 1);
-    snprintf(buf,128, "%d", kCAReverse);
+    snprintf(buf,128, "%d", A_REVERSE);
     setenv("ma_reverse", buf, 1);
-    snprintf(buf,128, "%d", kCABold);
+    snprintf(buf,128, "%d", A_BOLD);
     setenv("ma_bold", buf, 1);
-    snprintf(buf,128, "%d", kCAUnderline);
+    snprintf(buf,128, "%d", A_UNDERLINE);
     setenv("ma_underline", buf, 1);
-    snprintf(buf,128, "%d", kCAWhite);
+    snprintf(buf,128, "%d", COLOR_PAIR(1));
     setenv("ma_white", buf, 1);
-    snprintf(buf,128, "%d", kCABlue);
+    snprintf(buf,128, "%d", COLOR_PAIR(2));
     setenv("ma_blue", buf, 1);
-    snprintf(buf,128, "%d", kCACyan);
+    snprintf(buf,128, "%d", COLOR_PAIR(3));
     setenv("ma_cyan", buf, 1);
-    snprintf(buf,128, "%d", kCAGreen);
+    snprintf(buf,128, "%d", COLOR_PAIR(4));
     setenv("ma_green", buf, 1);
-    snprintf(buf,128, "%d", kCAYellow);
+    snprintf(buf,128, "%d", COLOR_PAIR(5));
     setenv("ma_yellow", buf, 1);
-    snprintf(buf,128, "%d", kCAMagenta);
+    snprintf(buf,128, "%d", COLOR_PAIR(6));
     setenv("ma_magenta", buf, 1);
-    snprintf(buf,128, "%d", kCARed);
+    snprintf(buf,128, "%d", COLOR_PAIR(7));
     setenv("ma_red", buf, 1);
 }
 
@@ -925,7 +908,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN(FALSE);
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "1.0.4", 1);
+    setenv("VERSION", "1.0.5", 1);
     setenv("MFILER4_DATAROOTDIR", DATAROOTDIR, 1);
 
     /// mfiler4のホームディレクトリを保存しておく ///
@@ -968,7 +951,7 @@ int main(int argc, char* argv[])
     srandom(1000);
 
     /// 端末の設定を保存 ///
-    //msave_ttysettings();
+    msave_ttysettings();
 
     /// 端末を初期化 ///
     mreset_tty();
@@ -1025,7 +1008,7 @@ int main(int argc, char* argv[])
     set_signal_mfiler();
 
     /// localeの設定 ///
-    if(gTerminalKanjiCode == kTKUtf8) setlocale(LC_CTYPE, "ja_JP.UTF-8");
+    //if(gTerminalKanjiCode == kTKUtf8) setlocale(LC_CTYPE, "ja_JP.UTF-8");
 
     /// atexit登録 ///
     atexit(atexit_fun);
@@ -1139,7 +1122,7 @@ int main(int argc, char* argv[])
     }
     
     /// カーシスの起動 ///
-    minitscr();
+    xinitscr();
 
     /// メインループ ///
     fd_set mask;
@@ -1150,51 +1133,32 @@ int main(int argc, char* argv[])
 
     while(gMainLoop == -1) {
         /// 描写 ///
-        mclear();
+        clear();
         view();
-        mrefresh();
+        refresh();
 
         const int maxy = mgetmaxy();
         mmove_immediately(maxy-2, 0);
 
         /// selectで入力待ち ///
         read_ok = mask;
-        if(!mkbuf_exist()) {     // キーボードのバッファがないならselect
-            if(xyzsh_job_num() > 0) {
-                struct timeval tv;
-                tv.tv_sec = 5;
-                tv.tv_usec = 0;
+        if(xyzsh_job_num() > 0) {
+            struct timeval tv;
+            tv.tv_sec = 5;
+            tv.tv_usec = 0;
 
-                select(5, &read_ok, NULL, NULL, &tv);
-            }
-            else {
-                select(5, &read_ok, NULL, NULL, NULL);
-            }
+            select(5, &read_ok, NULL, NULL, &tv);
+        }
+        else {
+            select(5, &read_ok, NULL, NULL, NULL);
         }
 
         /// キー処理 ///
-        if(FD_ISSET(0, &read_ok) || mkbuf_exist()) {    // キー入力があったか、キーボードのバッファがあるなら
+        if(FD_ISSET(0, &read_ok)) {
             int meta;
-            int key = mgetch_nonblock(&meta);
+            int key = xgetch(&meta);
 
-            /// ESCキー ///
-            if(key == -1) {
-            }
-            else if(meta) {
-                input(1, key);
-            }
-            
-            /// meta key ///
-            else if(key >= kKeyMetaFirst 
-                    && key <= kKeyMetaFirst + 127) 
-            {
-                input(1, key - kKeyMetaFirst );
-            }
-
-            /// normal key ///
-            else {
-               input(0, key);
-            }
+            input(meta, key);
         }
 
         /// ジョブ処理 ///
@@ -1202,7 +1166,7 @@ int main(int argc, char* argv[])
     }
 
     /// カーシス終わり ///
-    mendwin();
+    endwin();
 
     /// ジョブの消去 ///
     xyzsh_kill_all_jobs();
